0.1.7 (2014-11-14)
------------------
* Parse floats properly
* Properly decode \\n
* Complex keys can be set using strings

0.1.6 (2014-10-23)
------------------
* Fix bug that prevented pyhcl from working in a pyinstaller environment

0.1.5 (2014-10-15)
------------------
* Support escaped strings
* Support trailing commas
* Remove support for alternative boolean values

0.1.3 (2014-09-12)
------------------
* Update documentation
* Fix py3 support regarding bytes/strings
* Add tests for bytes and strings
* Support various boolean values

0.1.2 (2014-09-10)
------------------
* Add travis-ci tests, fix minor bugs in setup.py

0.1.0 (2014-09-05)
------------------
* Initial release
